# pymbrola

[![PyPI - Version](https://img.shields.io/pypi/v/pymbrola.svg)](https://pypi.org/project/pymbrola)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pymbrola.svg)](https://pypi.org/project/pymbrola)

-----


## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

MBROLA is currently available only on Linux-based systems like Ubuntu, or on Windows via the [Windows Susbsystem for Linux (WSL)](https://learn.microsoft.com/en-us/windows/wsl/install). Install MBROLA in your machine following the instructions in the [MBROLA repository](https://github.com/numediart/MBROLA). If you are using WSL, install MBROLA in WSL. After this, you should be ready to install **pymbrola** using pip.

```console
pip install pymbrola
```

## License

`pymbrola` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
